@@ -29,7 +29,7 @@ rgl.enum( type, shapes=1, lights=2, bboxdeco=3, viewpoint=4, material=5, backgro
 rgl.enum.attribtype <- function (attrib)
 rgl.enum( attrib, vertices=1, normals=2, colors=3, texcoords=4, dim=5, 
           texts=6, cex=7, adj=8, radii=9, centers=10, ids=11, 
-          usermatrix=12, types=13 )
+          usermatrix=12, types=13, flags=14 )
 
 rgl.enum.pixfmt <- function (fmt)
 rgl.enum( fmt, png=0 )
