@@ -17,7 +17,11 @@
 class Light : public SceneNode
 {
 public:
-  Light( PolarCoord in_position = PolarCoord(0.0,0.0) , bool in_viewpoint=true, Color ambient=Color(1.0f,1.0f,1.0f), Color diffuse=Color(1.0,1.0,1.0), Color specular=Color(1.0,1.0,1.0) );
+  Light( PolarCoord in_position = PolarCoord(0.0,0.0) , 
+  	 Vertex in_finposition=Vertex(0.0f,0.0f,0.0f), 
+  	 bool in_viewpoint=true, bool in_posisfinite=false, 
+  	 Color ambient=Color(1.0f,1.0f,1.0f), Color diffuse=Color(1.0,1.0,1.0), 
+  	 Color specular=Color(1.0,1.0,1.0) );
   void setup(RenderContext* renderContext);
 
   int getAttributeCount(AABox& bbox, AttribID attrib);
@@ -25,11 +29,13 @@ public:
 
 private:
   float position[4];
+  Vertex finposition;
   Color ambient;
   Color diffuse;
   Color specular;
   GLenum id;
   bool viewpoint;
+  bool posisfinite;
   friend class Scene;
 };
 
